.. _github-stats:

GitHub statistics for 3.10.0 (Dec 13, 2024)
===========================================

GitHub statistics for 2024/05/15 (tag: v3.9.0) - 2024/12/13

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 100 issues and merged 337 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/84?closed=1>`__

The following 128 authors contributed 1932 commits.

* abhi-jha
* Adam J. Stewart
* Aditi Gautam
* Aditya Vidyadhar Kamath
* Aishling Cooke
* Alan
* Alan Sosa
* Alice
* Aman Nijjar
* Ammar Qazi
* Ancheng
* anpaulan
* Anson0028
* Anthony Lee
* anTon
* Antony Lee
* Ayoub Gouasmi
* Brigitta Sipőcz
* Caitlin Hathaway
* cesar
* Charlie LeWarne
* Christian Mattsson
* ClarkeAC
* Clemens Brunner
* Clement Gilli
* cmp0xff
* Costa Paraskevopoulos
* dale
* Dani Pinyol
* Daniel Weiss
* Danny
* David Bakaj
* David Lowry-Duda
* David Meyer
* David Stansby
* dbakaj
* dependabot[bot]
* Diogo Cardoso
* Doron Behar
* Edgar Andrés Margffoy Tuay
* Elliott Sales de Andrade
* Eytan Adler
* farquh
* Felipe Cybis Pereira
* Filippo Balzaretti
* FMasson
* Francisco Cardozo
* Gavin S
* Greg Lucas
* haaris
* hannah
* Ian Thomas
* Illviljan
* James Addison
* James Spencer
* Jody Klymak
* john
* Jonas Eschle
* Jouni K. Seppänen
* juanis2112
* Juanita Gomez
* Justin Hendrick
* K900
* Kaustbh
* Kaustubh
* Kherim Willems
* Kyle Sunden
* Kyra Cho
* Larry Bradley
* litchi
* Lorenzo
* Lucx33
* Lumberbot (aka Jack)
* MadPhysicist
* malhar2460
* Martino Sorbaro
* Mathias Hauser
* Matthew Feickert
* Matthew Petroff
* Melissa Weber Mendonça
* Michael
* Michael Droettboom
* Michael Hinton
* MischaMegens2
* Moritz Wolter
* muchojp
* Nabil
* nakamura yuki
* odile
* OdileVidrine
* Oscar Gustafsson
* Panicks28
* Paul An
* Pedro Barão
* PedroBittarBarao
* Peter Talley
* Pierre-antoine Comby
* Pranav
* Pranav Raghu
* pre-commit-ci[bot]
* proximalf
* r3kste
* Randolf Scholz
* Refael Ackermann
* RickyP24
* rnhmjoj
* Ruth Comer
* Ryan May
* Sai Chaitanya, Sanivada
* saranti
* scaccol
* Scott Shambaugh
* Sean Smith
* Simon May
* simond07
* smcgrawDotNet
* Takumasa N
* Takumasa N.
* Takumasa Nakamura
* thiagoluisbecker
* Thomas A Caswell
* Tiago Lubiana
* Tim Hoffmann
* trananso
* Trygve Magnus Ræder
* Victor Liu
* vittoboa
* Xeniya Shoiko

GitHub issues and pull requests:

Pull Requests (337):

* :ghpull:`29299`: Merge v3.9.x into v3.10.x
* :ghpull:`29296`: Backport PR #29295 on branch v3.10.x (BLD: Pin meson-python to <0.17.0)
* :ghpull:`29290`: Backport PR #29254 on branch v3.10.x (DOC: Add note to align_labels())
* :ghpull:`29289`: Backport PR #29260 on branch v3.10.x (DOC: Better explanation of rcParams "patch.edgecolor" and "patch.force_edgecolor")
* :ghpull:`29288`: Backport PR #29285 on branch v3.10.x (Retarget PR#29175 to main)
* :ghpull:`29254`: DOC: Add note to align_labels()
* :ghpull:`29260`: DOC: Better explanation of rcParams "patch.edgecolor" and "patch.force_edgecolor"
* :ghpull:`29285`: Retarget PR#29175 to main
* :ghpull:`29286`: Backport PR #29274 on branch v3.10.x (Bump the actions group across 1 directory with 2 updates)
* :ghpull:`29274`: Bump the actions group across 1 directory with 2 updates
* :ghpull:`29283`: Backport PR #29272 on branch v3.10.x (DOC: Add section on translating between Axes and pyplot interface)
* :ghpull:`29272`: DOC: Add section on translating between Axes and pyplot interface
* :ghpull:`29279`: Backport PR #29265 on branch v3.10.x (DOC: Slightly improve the LineCollection docstring)
* :ghpull:`29276`: Backport PR #29247 on branch v3.10.x (Fix building freetype 2.6.1 on macOS clang 18)
* :ghpull:`29244`: Switch to a 3d rotation trackball implementation with path independence
* :ghpull:`29265`: DOC: Slightly improve the LineCollection docstring
* :ghpull:`29247`: Fix building freetype 2.6.1 on macOS clang 18
* :ghpull:`29268`: Bump the actions group with 2 updates
* :ghpull:`29266`: Backport PR #29251 on branch v3.10.x (Zizmor audit)
* :ghpull:`29269`: Backport PR #29267 on branch v3.10.x (Exclude pylab from mypy checks)
* :ghpull:`29267`: Exclude pylab from mypy checks
* :ghpull:`29251`: Zizmor audit
* :ghpull:`29255`: Backport PR #29249 on branch v3.10.x ([Bug Fix] Fix reverse mapping for _translate_tick_params)
* :ghpull:`29249`: [Bug Fix] Fix reverse mapping for _translate_tick_params
* :ghpull:`29250`: Backport PR #29243 on branch v3.10.x (Add quotes around [dev] in environment.yml)
* :ghpull:`29243`: Add quotes around [dev] in environment.yml
* :ghpull:`29246`: Backport PR #29240 on branch v3.10.x (DOC: Add plt.show() to introductory pyplot example)
* :ghpull:`29240`: DOC: Add plt.show() to introductory pyplot example
* :ghpull:`29239`: Backport PR #29236 on branch v3.10.x (ANI: Reduce Pillow frames to RGB when opaque)
* :ghpull:`29238`: Backport PR #29167 on branch v3.10.x (BUGFIX: use axes unit information in ConnectionPatch )
* :ghpull:`29236`: ANI: Reduce Pillow frames to RGB when opaque
* :ghpull:`29167`: BUGFIX: use axes unit information in ConnectionPatch
* :ghpull:`29232`: Merge branch v3.9.x into v3.10.x
* :ghpull:`29230`: Backport PR #29188 on branch v3.10.x (Bump pypa/cibuildwheel from 2.21.3 to 2.22.0 in the actions group)
* :ghpull:`29188`: Bump pypa/cibuildwheel from 2.21.3 to 2.22.0 in the actions group
* :ghpull:`29225`: Backport PR #29213 on branch v3.10.x (avoid-unnecessary-warning-in-_pcolorargs-function)
* :ghpull:`29211`: Backport PR #29133 on branch v3.10.x (Creating_parse_bar_color_args to unify color handling in plt.bar with precedence and sequence support for facecolor and edgecolor)
* :ghpull:`29177`: Backport PR #29148 on branch v3.10.x (Don't fail on equal-but-differently-named cmaps in qt figureoptions.)
* :ghpull:`29226`: Backport PR #29206 on branch v3.10.x (Skip more tests on pure-Wayland systems)
* :ghpull:`29206`: Skip more tests on pure-Wayland systems
* :ghpull:`29213`: avoid-unnecessary-warning-in-_pcolorargs-function
* :ghpull:`29210`: Backport PR #29209 on branch v3.10.x (FIX:  pcolormesh with no x y args and nearest interp)
* :ghpull:`29133`: Creating_parse_bar_color_args to unify color handling in plt.bar with precedence and sequence support for facecolor and edgecolor
* :ghpull:`29209`: FIX:  pcolormesh with no x y args and nearest interp
* :ghpull:`29200`: Backport PR #29182 on branch v3.10.x (Update backend_qt.py: parent not passed to __init__ on subplottool)
* :ghpull:`29207`: Backport PR #29169 on branch v3.10.x (Minor fixes to text intro explainer)
* :ghpull:`29169`: Minor fixes to text intro explainer
* :ghpull:`29159`: Pending warning for deprecated parameter 'vert' of box and violin on 3.10
* :ghpull:`29196`: Backport PR #29191 on branch v3.10.x (ci: Simplify 3.13t test setup)
* :ghpull:`29182`: Update backend_qt.py: parent not passed to __init__ on subplottool
* :ghpull:`29189`: Backport PR #28934 on branch v3.10.x (ci: Unpin micromamba again)
* :ghpull:`29186`: Backport PR #28335 on branch v3.10.x (DOC: do not posting LLM output as your own work)
* :ghpull:`28934`: ci: Unpin micromamba again
* :ghpull:`28335`: DOC: do not posting LLM output as your own work
* :ghpull:`29178`: Backport PR #29163 on branch v3.9.x (ci: Remove outdated pkg-config package on macOS)
* :ghpull:`29170`: Backport PR #29154 on branch v3.10.x (Relax conditions for warning on updating converters)
* :ghpull:`29154`: Relax conditions for warning on updating converters
* :ghpull:`29166`: Backport PR #29153 on branch v3.10.x (Bump codecov/codecov-action from 4 to 5 in the actions group)
* :ghpull:`29164`: Backport PR #29163 on branch v3.10.x (ci: Remove outdated pkg-config package on macOS)
* :ghpull:`29168`: Backport PR #29073 on branch v3.10.x (Update secondary_axis tutorial)
* :ghpull:`29073`: Update secondary_axis tutorial
* :ghpull:`29163`: ci: Remove outdated pkg-config package on macOS
* :ghpull:`29145`: Backport PR #29144 on branch v3.10.x (Use both TCL_SETVAR and TCL_SETVAR2 for tcl 9 support)
* :ghpull:`29144`: Use both TCL_SETVAR and TCL_SETVAR2 for tcl 9 support
* :ghpull:`29140`: Backport PR #29080 on branch v3.10.x (Updates the ``galleries/tutorials/artists.py`` file in response to issue #28920)
* :ghpull:`29080`: Updates the ``galleries/tutorials/artists.py`` file in response to issue #28920
* :ghpull:`29138`: Backport PR #29134 on branch v3.10.x (MNT: Temporarily skip failing test to unbreak CI)
* :ghpull:`29134`: MNT: Temporarily skip failing test to unbreak CI
* :ghpull:`29132`: Backport PR #29128 on branch v3.10.x (Tweak AutoMinorLocator docstring.)
* :ghpull:`29128`: Tweak AutoMinorLocator docstring.
* :ghpull:`29123`: Bump the actions group with 2 updates
* :ghpull:`29122`: Backport PR #29120 on branch v3.10.x (DOC: Switch nested pie example from cmaps to color_sequences)
* :ghpull:`29100`: Backport PR #29099 on branch v3.10.x (MNT: remove _ttconv.pyi)
* :ghpull:`29099`: MNT: remove _ttconv.pyi
* :ghpull:`29098`: Backport PR #29097 on branch v3.10.x (ENH: add back/forward buttons to osx backend move)
* :ghpull:`29097`: ENH: add back/forward buttons to osx backend move
* :ghpull:`29095`: Backport PR #29071 on branch v3.10.x (Bump pypa/gh-action-pypi-publish from 1.10.3 to 1.11.0 in the actions group)
* :ghpull:`29096`: Backport PR #29094 on branch v3.10.x (DOC: fix link in See Also section of axes.violin)
* :ghpull:`29092`: Backport PR #29088 on branch v3.10.x (DOC: Format aliases in kwargs tables)
* :ghpull:`29094`: DOC: fix link in See Also section of axes.violin
* :ghpull:`29091`: Backport PR #29085 on branch v3.10.x (FIX: Update GTK3Agg backend export name for consistency)
* :ghpull:`29088`: DOC: Format aliases in kwargs tables
* :ghpull:`29089`: Backport PR #29065 on branch v3.10.x (DOC: Update docstring of triplot())
* :ghpull:`29085`: FIX: Update GTK3Agg backend export name for consistency
* :ghpull:`29084`: Backport PR #29081 on branch v3.10.x (Document "none" as color value)
* :ghpull:`29065`: DOC: Update docstring of triplot()
* :ghpull:`29081`: Document "none" as color value
* :ghpull:`29061`: Backport PR #29024 on branch v3.10.x (Fix saving animations to transparent formats)
* :ghpull:`29069`: Backport PR #29068 on branch v3.10.x ([DOC] Fix indentation in sync_cmaps example)
* :ghpull:`29070`: Backport PR #29048 on branch v3.10.x (DOC: integrated pr workflow from contributing guide into install and workflow)
* :ghpull:`29048`: DOC: integrated pr workflow from contributing guide into install and workflow
* :ghpull:`29068`: [DOC] Fix indentation in sync_cmaps example
* :ghpull:`29024`: Fix saving animations to transparent formats
* :ghpull:`29059`: Cleanup converter docs and StrCategoryConverter behavior
* :ghpull:`29058`: [DOC] Update missing-references.json
* :ghpull:`29057`: DOC/TST: lock numpy<2.1 in environment.yml
* :ghpull:`29053`: Factor out common formats strings in LogFormatter, LogFormatterExponent.
* :ghpull:`28970`: Add explicit converter setting to Axis
* :ghpull:`28048`: Enables setting hatch linewidth in Patches and Collections, also fixes setting hatch linewidth by rcParams
* :ghpull:`29017`: DOC: Document preferred figure size for examples
* :ghpull:`28871`: updated contribution doc #28476
* :ghpull:`28453`: Stop relying on dead-reckoning mouse buttons for motion_notify_event.
* :ghpull:`28495`: ticker.EngFormatter: allow offset
* :ghpull:`29039`: MNT: Add provisional get_backend(resolve=False) flag
* :ghpull:`28946`: MNT: Deprecate plt.polar() with an existing non-polar Axes
* :ghpull:`29013`: FIX: auto_fmtxdate for constrained layout
* :ghpull:`29022`: Fixes AIX internal CI build break.
* :ghpull:`28830`: Feature: Support passing DataFrames to table.table
* :ghpull:`27766`: Return filename from save_figure
* :ghpull:`27167`: ENH: add long_axis property to colorbar
* :ghpull:`29021`: Update minimum pybind11 to 2.13.2
* :ghpull:`28863`: Improved documentation for quiver
* :ghpull:`29019`: Update requirements to add PyStemmer to doc-requirements and environment
* :ghpull:`28653`: Mnt/generalize plot varargs
* :ghpull:`28967`: Fix MSVC cast warnings
* :ghpull:`29016`: DOC: Better explain suptitle / supxlabel / supylabel naming
* :ghpull:`28842`: FT2Font extension improvements
* :ghpull:`28658`: New data → color pipeline
* :ghpull:`29012`: Bump required pybind11 to 2.13
* :ghpull:`29007`: MNT: Deprecate changing Figure.number
* :ghpull:`28861`: Break Artist._remove_method reference cycle
* :ghpull:`28478`: bugfix for ``PathSimplifier``
* :ghpull:`28992`: DOC: Refresh transform tree example
* :ghpull:`28890`: MNT: Add missing dependency to environment.yml
* :ghpull:`28354`: Add Quiverkey zorder option
* :ghpull:`28966`: Fix polar error bar cap orientation
* :ghpull:`28819`: Mark all extensions as free-threading safe
* :ghpull:`28986`: DOC: Add tags for 3D fill_between examples
* :ghpull:`28984`: DOC / BUG: Better example for 3D axlim_clip argument
* :ghpull:`20866`: Remove ttconv and implement Type-42 embedding using fontTools
* :ghpull:`28975`: Set guiEvent where applicable for gtk4.
* :ghpull:`28568`: added tags to mplot3d examples
* :ghpull:`28976`: Bump pypa/cibuildwheel from 2.21.2 to 2.21.3 in the actions group
* :ghpull:`28978`: CI: Resolve mypy stubtest build errors
* :ghpull:`28823`: Fix 3D rotation precession
* :ghpull:`28841`: Make mplot3d mouse rotation style adjustable
* :ghpull:`28971`: DOC: correct linestyle example and reference rcParams
* :ghpull:`28702`: [MNT]: #28701 separate the generation of polygon vertices in fill_between to enable resampling
* :ghpull:`28965`: Suggest imageio_ffmpeg to provide ffmpeg as animation writer.
* :ghpull:`28964`: FIX macos: Use the agg buffer_rgba rather than private attribute
* :ghpull:`28963`: Remove refs to outdated writers in animation.py.
* :ghpull:`28948`: Raise ValueError for RGB values outside the [0, 1] range in rgb_to_hsv function
* :ghpull:`28857`: Pybind11 cleanup
* :ghpull:`28949`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`28950`: Bump the actions group with 2 updates
* :ghpull:`28904`: Agg: Remove 16-bit limits
* :ghpull:`28856`: Convert remaining code to pybind11
* :ghpull:`28874`: Remove remaining 3.8 deprecations
* :ghpull:`28943`: DOC: Clarify the returned line of axhline()/axvline()
* :ghpull:`28935`: DOC: Fix invalid rcParam references
* :ghpull:`28942`: In colorbar docs, add ref from 'boundaries' doc to 'spacing' doc.
* :ghpull:`28933`: Switch AxLine.set_xy{1,2} to take a single argument.
* :ghpull:`28869`: ci: Bump build image on AppVeyor to MSVC 2019
* :ghpull:`28906`: Re-fix exception caching in dviread.
* :ghpull:`27349`: [ENH] Implement dynamic clipping to axes limits for 3D plots
* :ghpull:`28913`: DOC: Fix Axis.set_label reference
* :ghpull:`28911`: MNT: Fix double evaluation of _LazyTickList
* :ghpull:`28584`: MNT: Prevent users from erroneously using legend label API on Axis
* :ghpull:`28853`: MNT: Check the input sizes of regular X,Y in pcolorfast
* :ghpull:`28838`: TST: Fix minor issues in interactive backend test
* :ghpull:`28795`: MNT: Cleanup docstring substitution mechanisms
* :ghpull:`28897`: Fix minor issues in stubtest wrapper
* :ghpull:`28899`: Don't cache exception with traceback reference loop in dviread.
* :ghpull:`28888`: DOC: Better visualization for the default color cycle example
* :ghpull:`28896`: doc: specify non-python dependencies in dev install docs
* :ghpull:`28843`: MNT: Cleanup FontProperties __init__ API
* :ghpull:`28683`: MNT: Warn if fixed aspect overwrites explicitly set data limits
* :ghpull:`25645`: Fix issue with sketch not working on PathCollection in Agg
* :ghpull:`28886`: DOC: Cross-link Axes attributes
* :ghpull:`28880`: Remove 'in' from removal substitution for deprecation messages
* :ghpull:`28875`: DOC: Fix documentation of hist() kwarg lists
* :ghpull:`28825`: DOC: Fix non-working code object references
* :ghpull:`28862`: Improve pie chart error messages
* :ghpull:`28844`: DOC: Add illustration to Figure.subplots_adjust
* :ghpull:`28588`: Fix scaling in Tk on non-Windows systems
* :ghpull:`28849`: DOC: Mark subfigures as no longer provisional
* :ghpull:`26000`: making onselect a keyword argument on selectors
* :ghpull:`26013`: Support unhashable callbacks in CallbackRegistry
* :ghpull:`27011`: Convert Agg extension to pybind11
* :ghpull:`28845`: In examples, prefer named locations rather than location numbers.
* :ghpull:`27218`: API: finish LocationEvent.lastevent removal
* :ghpull:`26870`: Removed the deprecated code from axis.py
* :ghpull:`27996`: Create ``InsetIndicator`` artist
* :ghpull:`28532`: TYP: Fix xycoords and friends
* :ghpull:`28785`: Convert ft2font extension to pybind11
* :ghpull:`28815`: DOC: Document policy on colormaps and styles
* :ghpull:`28826`: MNT: Replace _docstring.dedent_interpd by its alias _docstring.interpd
* :ghpull:`27567`: DOC: batch of tags
* :ghpull:`27302`: Tags for simple_scatter.py demo
* :ghpull:`28820`: DOC: Fix missing cross-reference checks for sphinx-tags
* :ghpull:`28786`: Handle single color in ContourSet
* :ghpull:`28808`: DOC: Add a plot to margins() to visualize the effect
* :ghpull:`27938`: feat: add dunder method for math operations on Axes Size divider
* :ghpull:`28569`: Adding tags to many examples
* :ghpull:`28183`: Expire deprecations
* :ghpull:`28801`: DOC: Clarify AxLine.set_xy2 / AxLine.set_slope
* :ghpull:`28788`: TST: Skip webp tests if it isn't available
* :ghpull:`28550`: Remove internal use of ``Artist.figure``
* :ghpull:`28767`: MNT: expire ``ContourSet`` deprecations
* :ghpull:`28755`: TYP: Add typing for internal _tri extension
* :ghpull:`28765`: Add tests for most of FT2Font, and fix some bugs
* :ghpull:`28781`: TST: Fix test_pickle_load_from_subprocess in a dirty tree
* :ghpull:`28783`: Fix places where "auto" was not listed as valid interpolation_stage.
* :ghpull:`28779`: DOC/TST: lock numpy < 2.1
* :ghpull:`28771`: Ensure SketchParams is always fully initialized
* :ghpull:`28375`: FIX: Made AffineDeltaTransform pass-through properly
* :ghpull:`28454`: MultivarColormap and BivarColormap
* :ghpull:`27891`: Refactor some parts of ft2font extension
* :ghpull:`28752`: quick fix dev build by locking out numpy version that's breaking things
* :ghpull:`28749`: Add sphinxcontrib-video to environment.yml
* :ghpull:`27851`: Add ten-color accessible color cycle as style sheet
* :ghpull:`28501`: ConciseDateFormatter's offset string is correct on an inverted axis
* :ghpull:`28734`: Compressed layout moves suptitle
* :ghpull:`28736`: Simplify some code in dviread
* :ghpull:`28347`: Doc: added triage section to new contributor docs
* :ghpull:`28735`: ci: Avoid setuptools 72.2.0 when installing kiwi on PyPy
* :ghpull:`28728`: MNT: Deprecate reimported functions in top-level namespace
* :ghpull:`28730`: MNT: Don't rely on RcParams being a dict subclass in internal code
* :ghpull:`28714`: Simplify _api.warn_external on Python 3.12+
* :ghpull:`28727`: MNT: Better workaround for format_cursor_data on ScalarMappables
* :ghpull:`28725`: Stop disabling FH4 Exception Handling on MSVC
* :ghpull:`28711`: Merge branch v3.9.x into main
* :ghpull:`28713`: DOC: Add a few more notes to release guide
* :ghpull:`28720`: DOC: Clarify axhline() uses axes coordinates
* :ghpull:`28718`: DOC: Update missing references for numpydoc 1.8.0
* :ghpull:`28710`: DOC: clarify alpha handling for indicate_inset[_zoom]
* :ghpull:`28704`: Fixed arrowstyle doc interpolation in FancyPatch.set_arrow() #28698.
* :ghpull:`28709`: Bump actions/attest-build-provenance from 1.4.0 to 1.4.1 in the actions group
* :ghpull:`28707`: Avoid division-by-zero in Sketch::Sketch
* :ghpull:`28610`: CI: Add CI to test matplotlib against free-threaded Python
* :ghpull:`28262`: Fix PolygonSelector cursor to temporarily hide during active zoom/pan
* :ghpull:`28670`: API: deprecate unused helper in patch._Styles
* :ghpull:`28589`: Qt embedding example: Separate drawing and data retrieval timers
* :ghpull:`28655`: Inline annotation and PGF user demos
* :ghpull:`28654`: DOC: Remove long uninstructive examples
* :ghpull:`28652`: Fix docstring style inconsistencies in lines.py
* :ghpull:`28641`: DOC: Standardize example titles - part 2
* :ghpull:`28642`: DOC: Simplify heatmap example
* :ghpull:`28638`: DOC: Remove hint on PRs from origin/main
* :ghpull:`28587`: Added dark-mode diverging colormaps
* :ghpull:`28546`: DOC: Clarify/simplify example of multiple images with one colorbar
* :ghpull:`28613`: Added documentation for parameters vmin and vmax inside specgram function.
* :ghpull:`28627`: DOC: Bump minimum Sphinx to 5.1.0
* :ghpull:`28628`: DOC: Sub-structure next API changes overview
* :ghpull:`28629`: FIX: ``Axis.set_in_layout`` respected
* :ghpull:`28575`: Add branch tracking to development workflow instructions
* :ghpull:`28616`: CI: Build docs on latest Python
* :ghpull:`28617`: DOC: Enable parallel builds
* :ghpull:`28544`: DOC: Standardize example titles
* :ghpull:`28615`: DOC: hack to suppress sphinx-gallery 17.0 warning
* :ghpull:`28293`: BLD: Enable building Python 3.13 wheels for nightlies
* :ghpull:`27385`: Fix 3D lines being visible when behind camera
* :ghpull:`28609`: svg: Ensure marker-only lines get URLs
* :ghpull:`28599`: Upgrade code to Python 3.10
* :ghpull:`28593`: Update ruff to 0.2.0
* :ghpull:`28603`: Simplify ttconv python<->C++ conversion using std::optional.
* :ghpull:`28557`: DOC: apply toc styling to remove nesting
* :ghpull:`28542`: CI: adjust pins in mypy GHA job
* :ghpull:`28504`: Changes in SVG backend to improve compatibility with Affinity designer
* :ghpull:`28122`: Disable clipping in Agg resamplers.
* :ghpull:`28597`: Pin PyQt6 back on Ubuntu 20.04
* :ghpull:`28073`: Add support for multiple hatches, edgecolors and linewidths in histograms
* :ghpull:`28594`: MNT: Raise on GeoAxes limits manipulation
* :ghpull:`28312`: Remove one indirection layer in ToolSetCursor.
* :ghpull:`28573`: ENH: include property name in artist AttributeError
* :ghpull:`28503`: Bump minimum Python to 3.10
* :ghpull:`28525`: FIX: colorbar pad for ``ImageGrid``
* :ghpull:`28558`: DOC: Change _make_image signature to numpydoc
* :ghpull:`28061`: API: add antialiased to interpolation-stage in image
* :ghpull:`28536`: [svg] Add rcParam["svg.id"] to add a top-level id attribute to <svg>
* :ghpull:`28540`: Subfigures become stale when their artists are stale
* :ghpull:`28177`: Rationalise artist get_figure methods; make figure attribute a property
* :ghpull:`28527`: DOC: improve tagging guidelines page
* :ghpull:`28530`: DOC: Simplify axhspan example
* :ghpull:`28537`: DOC: Update timeline example for newer releases
* :ghpull:`27833`: [SVG] Introduce sequential ID-generation scheme for clip-paths.
* :ghpull:`28512`: DOC: Fix version switcher for stable docs
* :ghpull:`28492`: MNT: Remove PolyQuadMesh deprecations
* :ghpull:`28509`: CI: Use micromamba on AppVeyor
* :ghpull:`28510`: Merge v3.9.1 release into main
* :ghpull:`28494`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`28497`: Add words to ignore for codespell
* :ghpull:`28455`: Expand ticklabels_rotation example to cover rotating default ticklabels.
* :ghpull:`28282`: DOC: clarify no-build-isolation & mypy ignoring new functions
* :ghpull:`28306`: Fixed PolarAxes not using fmt_xdata and added simple test (#4568)
* :ghpull:`28400`: DOC: Improve doc wording of data parameter
* :ghpull:`28225`: [ENH]: fill_between extended to 3D
* :ghpull:`28371`: Bump pypa/cibuildwheel from 2.18.1 to 2.19.0 in the actions group
* :ghpull:`28390`: Inline RendererBase._get_text_path_transform.
* :ghpull:`28381`: Take hinting rcParam into account in MathTextParser cache.
* :ghpull:`28363`: flip subfigures axes to match subplots
* :ghpull:`28340`: Fix missing font error when using MiKTeX
* :ghpull:`28379`: PathEffectsRenderer can plainly inherit RendererBase._draw_text_as_path.
* :ghpull:`28275`: Revive sanitizing default filenames extracted from UI window titles
* :ghpull:`28360`: DOC: fixed code for testing check figures equal example
* :ghpull:`28370`: Reorder Axes3D parameters semantically.
* :ghpull:`28350`: Typo in communication guide: extensiblity -> extensibility
* :ghpull:`28290`: Introduce natural 3D rotation with mouse
* :ghpull:`28186`: apply unary minus spacing directly after equals sign
* :ghpull:`28311`: Update 3D orientation indication right away
* :ghpull:`28300`: Faster title alignment
* :ghpull:`28313`: Factor out handling of missing spines in alignment calculations.
* :ghpull:`28196`: TST: add timeouts to font_manager + threading test
* :ghpull:`28279`: Doc/ipython dep
* :ghpull:`28091`: [MNT]: create build-requirements.txt and update dev-requirements.txt
* :ghpull:`27992`: Add warning for multiple pyplot.figure calls with same ID
* :ghpull:`28238`: DOC: Update release guide to match current automations
* :ghpull:`28232`: Merge v3.9.0 release into main
* :ghpull:`28228`: DOC: Fix typo in release_guide.rst
* :ghpull:`28074`: Add  ``orientation`` parameter to Boxplot and deprecate ``vert``
* :ghpull:`27998`: Add a new ``orientation`` parameter to Violinplot and deprecate ``vert``
* :ghpull:`28217`: Better group logging of font handling by texmanager.
* :ghpull:`28130`: Clarify the role of out_mask and out_alpha in _make_image.
* :ghpull:`28201`: Deprecate ``Poly3DCollection.get_vector``
* :ghpull:`28046`: DOC: Clarify merge policy
* :ghpull:`26893`: PGF: Consistently set LaTeX document font size
* :ghpull:`28156`: Don't set savefig.facecolor/edgecolor in dark_background/538 styles.
* :ghpull:`28030`: Fix #28016: wrong lower ylim when baseline=None on stairs
* :ghpull:`28127`: GOV: write up policy on not updating req for CVEs in dependencies
* :ghpull:`28106`: Fix: [Bug]: Setting norm by string doesn't work for hexbin #28105
* :ghpull:`28143`: Merge branch v3.9.x into main
* :ghpull:`28133`: Make ``functions`` param to secondary_x/yaxis not keyword-only.
* :ghpull:`28083`: Convert TensorFlow to numpy for plots
* :ghpull:`28116`: FIX: Correct names of aliased cmaps
* :ghpull:`28118`: Remove redundant baseline tests in test_image.
* :ghpull:`28093`: Minor maintenance on pgf docs/backends.
* :ghpull:`27818`: Set polygon offsets for log scaled hexbin
* :ghpull:`28058`: TYP: add float to to_rgba x type
* :ghpull:`27964`: BUG: Fix NonUniformImage with nonlinear scale
* :ghpull:`28054`: DOC: Clarify that parameters to gridded data plotting functions are p…
* :ghpull:`27882`: Deleting all images that have passed tests before upload
* :ghpull:`28033`: API: warn if stairs used in way that is likely not desired
* :ghpull:`27786`: Deprecate positional use of most arguments of plotting functions
* :ghpull:`28025`: DOC: Clarify interface terminology
* :ghpull:`28043`: MNT: Add git blame ignore for docstring parameter indentation fix
* :ghpull:`28037`: DOC: Fix inconsistent spacing in some docstrings in _axes.py
* :ghpull:`28031`: Be more specific in findobj return type

Issues (100):

* :ghissue:`29298`: [Doc]: The link at "see also" is incorrect. (Axes.violin)
* :ghissue:`29248`: [Bug]: Figure.align_labels() confused by GridSpecFromSubplotSpec
* :ghissue:`26738`: Improve LineCollection docstring further
* :ghissue:`29263`: [Bug]: mypy failures in CI
* :ghissue:`27416`: [Bug]: get_tick_params on xaxis shows wrong keywords
* :ghissue:`29241`: [Bug]: Instructions for setting up conda dev environment in environment.yml give issues with MacOS/zsh
* :ghissue:`29227`: [Bug]: Introductory example on the pyplot API page does not show - missing plt.show()
* :ghissue:`29190`: [Bug]: inconsistent ‘animation.FuncAnimation’ between display and save
* :ghissue:`29090`: [MNT]: More consistent color parameters for bar()
* :ghissue:`29179`: [Bug]: Incorrect pcolormesh when shading='nearest' and only the mesh data C is provided.
* :ghissue:`29067`: [Bug]: ``secondary_xaxis`` produces ticks at incorrect locations
* :ghissue:`29126`: [Bug]: TkAgg backend is broken with tcl/tk 9.0
* :ghissue:`29045`: [ENH]: implement back/forward buttons on mouse move events on macOS
* :ghissue:`27173`: [Bug]: Gifs no longer create transparent background
* :ghissue:`19229`: Add public API for setting an axis unit converter
* :ghissue:`21108`: [Bug]: Hatch linewidths cannot be modified in an  rcParam context
* :ghissue:`27784`: [Bug]: Polar plot error bars don't rotate with angle for ``set_theta_direction`` and ``set_theta_offset``
* :ghissue:`29011`: [Bug]: Figure.autofmt_xdate() not working in presence of colorbar with constrained layout
* :ghissue:`29020`: AIX internal CI build break #Matplotlib
* :ghissue:`28726`: feature request: support passing DataFrames to table.table
* :ghissue:`28570`: [MNT]: Try improving doc build speed by using PyStemmer
* :ghissue:`13388`: Typo in the figure API (fig.suptitle)
* :ghissue:`28994`: [Bug]: Figure Number Gives Type Error
* :ghissue:`28985`: [ENH]: Cannot disable coordinate display in ToolManager/Toolbar (it's doable in NavigationToolbar2)
* :ghissue:`17914`: ``PathSimplifier`` fails to ignore ``CLOSEPOLY`` vertices
* :ghissue:`28885`: [Bug]: Strange errorbar caps when polar axes have non-default theta direction or theta zero location
* :ghissue:`12418`: replace ttconv for ps/pdf
* :ghissue:`28962`: [Bug]: gtk4 backend does not set guiEvent attribute
* :ghissue:`28408`: [ENH]: mplot3d mouse rotation style
* :ghissue:`28701`: [MNT]: Separate the generation of polygon vertices from ``_fill_between_x_or_y``
* :ghissue:`28941`: [Bug]: unexplicit error message when using ``matplotlib.colors.rgb_to_hsv()`` with wrong input
* :ghissue:`23846`: [MNT]: Pybind11 transition plan
* :ghissue:`28866`: Possible memory leak in pybind11 migration
* :ghissue:`26368`: [Bug]: Long audio files result in incomplete spectrogram visualizations
* :ghissue:`23826`: [Bug]: Overflow of 16-bit integer in Agg renderer causes PolyCollections to be drawn at incorrect locations
* :ghissue:`28927`: [Bug]: Enforce that Line data modifications are sequences
* :ghissue:`12312`: colorbar(boundaries=...) doesn't work so well with nonlinear norms
* :ghissue:`28800`: [ENH]: AxLine xy1/xy2 setters should take xy as single parameters, (possibly) not separate ones
* :ghissue:`28893`: [Bug]: Lines between points are invisible when there are more than 7 subfigures per row
* :ghissue:`28908`: [Bug]: Possible performance issue with _LazyTickList
* :ghissue:`27971`: [Bug]: ax.xaxis.set_label(...) doesn't set the x-axis label
* :ghissue:`28059`: [Bug]: pcolorfast should validate that regularly spaced X or Y inputs have the right size
* :ghissue:`28892`: [Doc]: Be more specific on dependencies that need to be installed for a "reasonable" dev environment
* :ghissue:`19693`: path.sketch doesn't apply to PolyCollection
* :ghissue:`28873`: [Bug]: hist()'s doc for edgecolors/facecolors does not match behavior (which is itself not very consistent)
* :ghissue:`23005`: [Doc]: Add figure to ``subplots_adjust``
* :ghissue:`25947`: [Doc]: Subfigures still marked as provisional
* :ghissue:`26012`: [Bug]: "Unhashable type" when event callback is a method of a ``dict`` subclass
* :ghissue:`23425`: [Bug]: Axes.indicate_inset connectors affect constrained layout
* :ghissue:`23424`: [Bug]: Axes.indicate_inset(linewidth=...) doesn't affect connectors
* :ghissue:`19768`: Overlay created by ``Axes.indicate_inset_zoom`` does not adjust when changing inset ranges
* :ghissue:`27673`: [Doc]: Confusing page on color changes
* :ghissue:`28782`: [Bug]: String ``contour(colors)`` gives confusing error when ``extend`` used
* :ghissue:`27930`: [ENH]: Make axes_grid1.Size more math friendly.
* :ghissue:`28372`: [Bug]: AffineDeltaTransform does not appear to invalidate properly
* :ghissue:`27866`: [Bug]: Adding suptitle in compressed layout causes weird spacing
* :ghissue:`28731`: [Bug]: Plotting numpy.array of dtype float32 with pyplot.imshow and specified colors.LogNorm produces wrong colors
* :ghissue:`28715`: [Bug]: CI doc builds fail since a couple of days
* :ghissue:`28698`: [bug]: arrowstyle doc interpolation in FancyPatch.set_arrow()
* :ghissue:`28669`: [Bug]: division-by-zero error in Sketch::Sketch with Agg backend
* :ghissue:`28548`: [Doc]: matplotlib.pyplot.specgram parameters vmin and vmax are not documented
* :ghissue:`28165`: [Bug]: PolygonSelector should hide itself when zoom/pan is active
* :ghissue:`18608`: Feature proposal: "Dark mode" divergent colormaps
* :ghissue:`28623`: [Bug]: ``Axis.set_in_layout`` not respected?
* :ghissue:`6305`: Matplotlib 3D plot - parametric curve “wraparound” from certain perspectives
* :ghissue:`28595`: [Bug]: set_url without effect for instances of Line2D with linestyle 'none'
* :ghissue:`20910`: [Bug]: Exported SVG files are no longer imported Affinity Designer correctly
* :ghissue:`28600`: [TST] Upcoming dependency test failures
* :ghissue:`26718`: [Bug]: stacked histogram does not properly handle edgecolor and hatches
* :ghissue:`28590`: [ENH]: Geo Projections support for inverting axis
* :ghissue:`27954`: [ENH]: Iterables in grouped histogram labels
* :ghissue:`27878`: [ENH]: AttributeError('... got an unexpected keyword argument ...') should set the .name attribute to the keyword
* :ghissue:`28489`: [TST] Upcoming dependency test failures
* :ghissue:`28343`: [Bug]: inconsistent colorbar pad for ``ImageGrid`` with ``cbar_mode="single"``
* :ghissue:`28535`: [ENH]: Add id attribute to top level svg tag
* :ghissue:`28170`: [Doc]: ``get_figure`` may return a ``SubFigure``
* :ghissue:`27831`: [Bug]: Nondeterminism in SVG clipPath element id attributes
* :ghissue:`4568`: Add ``fmt_r`` and ``fmt_theta`` methods to polar axes
* :ghissue:`28105`: [Bug]: Setting norm by string doesn't work for hexbin
* :ghissue:`28142`: [ENH]: Add fill between support for 3D plots
* :ghissue:`28344`: [Bug]: subfigures are added in column major order
* :ghissue:`28212`: [Bug]: Matplotlib not work with MiKTeX.
* :ghissue:`28288`: [ENH]: Natural 3D rotation with mouse
* :ghissue:`28180`: [Bug]: mathtext should distinguish between unary and binary minus
* :ghissue:`26150`: [Bug]: Savefig slow with subplots
* :ghissue:`28310`: [Bug]: orientation indication shows up late in mplot3d, and then lingers
* :ghissue:`16263`: Apply NEP29 (time-limited support) to IPython
* :ghissue:`28192`: [MNT]: Essential build requirements not included in dev-requirements
* :ghissue:`27978`: [Bug]:  strange behaviour when redefining figure size
* :ghissue:`13435`: boxplot/violinplot orientation-setting API
* :ghissue:`28199`: [MNT]: Misleading function name ``Poly3DCollection.get_vector()``
* :ghissue:`26892`: [Bug]: PGF font size mismatch between measurement and output
* :ghissue:`28016`: [Bug]: Unexpected ylim of stairs with baseline=None
* :ghissue:`28114`: [Bug]: mpl.colormaps[ "Grays" ].name is "Greys", not "Grays"
* :ghissue:`18045`: Cannot access hexbin data when ``xscale='log'`` and ``yscale='log'`` are set.
* :ghissue:`27820`: [Bug]: Logscale Axis + NonUniformImage + GUI move tool = Distortion
* :ghissue:`28047`: [Bug]: plt.barbs is a command that cannot be passed in a c parameter by parameter name, but can be passed in the form of a positional parameter
* :ghissue:`23400`: Only upload failed images on failure
* :ghissue:`26752`: [Bug]: ``ax.stairs()`` creates inaccurate ``fill`` for the plot
* :ghissue:`21817`: [Doc/Dev]: style guide claims "object oriented" is verboten.


Previous GitHub statistics
--------------------------

.. toctree::
    :maxdepth: 1
    :glob:
    :reversed:

    prev_whats_new/github_stats_*
